==> smtp-credentials-cdk-construct-1.0.4.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [1.0.4](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/compare/v1.0.3...v1.0.4) (2021-03-16)


### Bug Fixes

* amend NuGet package ID ([9ba00f0](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/commit/9ba00f0e4f42cecba32a7ea84409908293ff3d10))

### [1.0.3](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/compare/v1.0.2...v1.0.3) (2021-03-16)


### Bug Fixes

* correct link in `README.md` ([5f8c316](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/commit/5f8c3166d220c8af1f1760004ceeb8a85baeacaf))

### [1.0.2](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/compare/v1.0.1...v1.0.2) (2021-03-16)


### Bug Fixes

* ensure that `package.json` is updated, by executing `npx projen` ([f777f5e](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/commit/f777f5e352c55425d4b0be523ab673382108978c))
* specify public NPM access ([f5f7fda](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/commit/f5f7fda3b5bb28652254e358998ec00631a84482))
* use absolute URLs in `README.md` ([6cdb9d7](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/commit/6cdb9d716ec62f6fe6dc0d0515eb29709f8af030))

### [1.0.1](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/compare/v1.0.0...v1.0.1) (2021-03-16)


### Bug Fixes

* specify Maven endpoint ([8f4aeda](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/commit/8f4aedac378e72317f2b5c4e922c1a2b4619695d))

## 1.0.0 (2021-03-16)

==> smtp-credentials-cdk-construct-1.0.6.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [1.0.6](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/compare/v1.0.5...v1.0.6) (2021-03-16)


### Bug Fixes

* add `@charlesdotfish/smtp-credentials-cdk-construct` to the `awscdk.io` catalog ([a4cbe26](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/commit/a4cbe26fbf2074536b0aa4d63e7743a0733a824a))

### [1.0.5](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/compare/v1.0.4...v1.0.5) (2021-03-16)

### [1.0.4](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/compare/v1.0.3...v1.0.4) (2021-03-16)


### Bug Fixes

* amend NuGet package ID ([9ba00f0](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/commit/9ba00f0e4f42cecba32a7ea84409908293ff3d10))

### [1.0.3](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/compare/v1.0.2...v1.0.3) (2021-03-16)


### Bug Fixes

* correct link in `README.md` ([5f8c316](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/commit/5f8c3166d220c8af1f1760004ceeb8a85baeacaf))

### [1.0.2](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/compare/v1.0.1...v1.0.2) (2021-03-16)


### Bug Fixes

* ensure that `package.json` is updated, by executing `npx projen` ([f777f5e](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/commit/f777f5e352c55425d4b0be523ab673382108978c))
* specify public NPM access ([f5f7fda](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/commit/f5f7fda3b5bb28652254e358998ec00631a84482))
* use absolute URLs in `README.md` ([6cdb9d7](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/commit/6cdb9d716ec62f6fe6dc0d0515eb29709f8af030))

### [1.0.1](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/compare/v1.0.0...v1.0.1) (2021-03-16)


### Bug Fixes

* specify Maven endpoint ([8f4aeda](https://github.com/charlesdotfish/smtp-credentials-cdk-construct/commit/8f4aedac378e72317f2b5c4e922c1a2b4619695d))

## 1.0.0 (2021-03-16)
